{ config, pkgs, ... }: {
  # https://docs.gitea.com/administration/customizing-gitea
  systemd.tmpfiles.rules = [
    "d '${config.services.forgejo.customDir}/templates' - forgejo forgejo - -"
    "d '${config.services.forgejo.customDir}/public' - forgejo forgejo - -"
    "d '${config.services.forgejo.customDir}/public/assets' - forgejo forgejo - -"
    "L+ '${config.services.forgejo.customDir}/public/assets/img' - forgejo forgejo - ${
      ./img
    }"
    "L+ '${config.services.forgejo.customDir}/templates/home.tmpl' - forgejo forgejo - ${
      ./home.tmpl
    }"
  ];

  services = {
    # /var/lib/forgejo
    forgejo = {
      enable = true;
      package = pkgs.forgejo;
      database.type = "postgres";
      secrets.mailer.PASSWD = "/etc/secrets/forge-email";
      settings = {
        DEFAULT = {
          APP_NAME = "Forgejo: hnjklkvm,l;sla";
        };

        "ui.meta" = {
          AUTHOR = "Forgejo";
          DESCRIPTION = "Wiggly wiggly";
        };

        server = {
          DOMAIN = "forge.catnip.ee";
          HTTP_PORT = 4005;
          SSH_PORT = 2222;
          START_SSH_SERVER = true;
          ROOT_URL = "https://${config.services.forgejo.settings.server.DOMAIN}";
        };
        mailer = {
          ENABLED = true;
          FROM = "forge@catnip.ee";
          PROTOCOL = "smtps";
          SMTP_ADDR = "mx1.sly.ee";
          SMTP_PORT = 465;
          USER = "forge@catnip.ee";
        };
        service = {
          DISABLE_REGISTRATION = true;
        };

        federation = {
          ENABLED = true;
        };
      };
    };

    # /var/lib/gitea-runner
    gitea-actions-runner = {
      package = pkgs.forgejo-actions-runner;
      instances = {
        forge = {
          enable = true;
          url = "https://forge.catnip.ee";
          name = "runner";
          labels = [
            "latest-debian:docker://node:current"
            "latest-alpine:docker://node:current-alpine"
          ];
          tokenFile = "/etc/secrets/gitea-actions-runner.env";
        };
      };
    };

    caddy.virtualHosts."forge.catnip.ee".extraConfig = ''
      tls {
        dns cloudflare {env.CLOUDFLARE_API_TOKEN}
        resolvers 1.1.1.1
      }

      reverse_proxy :${toString config.services.forgejo.settings.server.HTTP_PORT}
    '';

    borgbackup.jobs."borgbase" = {
      paths = [
        "/var/lib/forgejo"
        "/var/lib/gitea-runner"
      ];
    };
  };

  networking.firewall.allowedTCPPorts = [
    config.services.forgejo.settings.server.SSH_PORT
  ];
}
